
--[[
Copyright (c) 2014 Lars Lönneker

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
--]]

-- Space Taxi Clone --
----------------------
sti = require("source.STI")
require("source.Common")
require("source.Animation")

-- Image filter --
love.graphics.setDefaultFilter("nearest", "nearest")

FONT = {
  small = love.graphics.newFont("assets/font.ttf", 8),
  medium = love.graphics.newFont("assets/font.ttf", 13),
}

-- Dependencies --
local SceneManager = require("source.SceneManager")
local MenuScene = require("source.MenuScene")
local GameScene = require("source.GameScene")


function love.load() 
  -- Initialize window
  WIDTH, HEIGHT = 960, 540 -- Window dimensions
  VSYNC, FULLSCREEN = true, false
  love.window.setMode(WIDTH, HEIGHT, {vsync = VSYNC, fullscreen = FULLSCREEN})
  SCREENWIDTH, SCREENHEIGHT = love.window.getDimensions()
  SCALEX, SCALEY = 1, 1
  
  math.randomseed(os.time())
  
  -- Set Resolution
  setResolution(320, 180) -- work values
  
  -- Setup scenes
  SceneManager.newScene(MenuScene, "MenuScene")
  SceneManager.newScene(GameScene, "GameScene")
  SceneManager.setScene("GameScene")
end


function love.update(dt)
  SceneManager.update(dt)
end


function love.draw()
  love.graphics.scale(SCALEX, SCALEY)
  SceneManager.draw()
end


function love.keypressed(key)
  SceneManager.keypressed(key)
end

