
-- Game Scene --
----------------
local GameScene = {}

-- Dependencies --
------------------
local Level = require("source.Level")
local Ui = require("source.Ui")
local Taxi = require("source.Taxi")

-- Declarations --
------------------
local map

local function setupLevel(v)
  map = Level:load(v)
  if player then
    player:respawn(Level.pads["Gas Station"].x + Level.pads["Gas Station"].w / 2 - 16, Level.pads["Gas Station"].y - 10)
  else
    player = Taxi:new(Level.pads["Gas Station"].x + Level.pads["Gas Station"].w / 2 - 16, Level.pads["Gas Station"].y - 10)
  end
  return map
end


function GameScene:enter()
  player = nil
  pause = false
  self.level = 1
  setupLevel(self.level)
  Ui:init()
end


function GameScene:leave()
end


function GameScene:update(dt)
  
  -- Level progress --
  --------------------
  if map.completed then
    self.level = self.level + 1
    setupLevel(self.level)
  end
  
  -- Update everything --
  -----------------------
  if not pause then
    if not player.removed then player:update(dt) end
    Level:update(dt)
    Ui:update(dt)
  end
end


function GameScene:draw()
  Ui:draw()
  love.graphics.setScissor(0, 0, WIDTH*SCALEX, HEIGHT*SCALEY-64)
  Level:draw()
  love.graphics.setScissor()
  if not player.removed then player:draw() end
end


function GameScene:keypressed(key)
  player:keypressed(key)
  if key == "escape" then love.event.quit() end
  if key == "r" then self:enter() end
  if key == "p" then pause = not pause end
end

return GameScene
